( cd usr/lib64 ; rm -rf libaspell.so.15 )
( cd usr/lib64 ; ln -sf libaspell.so.15.1.4 libaspell.so.15 )
( cd usr/lib64 ; rm -rf libaspell.so )
( cd usr/lib64 ; ln -sf libaspell.so.15.1.4 libaspell.so )
( cd usr/lib64 ; rm -rf libpspell.so.15 )
( cd usr/lib64 ; ln -sf libpspell.so.15.1.4 libpspell.so.15 )
( cd usr/lib64 ; rm -rf libpspell.so )
( cd usr/lib64 ; ln -sf libpspell.so.15.1.4 libpspell.so )
